@@ -2,7 +2,7 @@ package CSS::DOM;
 
 use 5.008002;
 
-$VERSION = '0.13';
+$VERSION = '0.16';
 
 use   # to keep CPANTS happy :-)
    strict;
@@ -161,6 +161,7 @@ sub compute_style {
 					 /^important\z/i
 					 ? "\4" : "\3"
 					) . "\1\0\0\0";
+					no warnings 'uninitialized';
 					$spec ge $specificity{$p} and
 					  $style->setProperty(
 					   $p, $sty->getPropertyValue($p)
@@ -273,13 +274,15 @@ sub hasFeature {
 
                               !()__END__()!
 
+=encoding utf8
+
 =head1 NAME
 
 CSS::DOM - Document Object Model for Cascading Style Sheets
 
 =head1 VERSION
 
-Version 0.13
+Version 0.16
 
 This is an alpha version. The API is still subject to change. Many features
 have not been implemented yet (but patches would be welcome :-).
@@ -646,7 +649,7 @@ Array ref of style sheets that the HTML document defines or links to.
 
 =item element
 
-The element
+The element, as an L<HTML::DOM::Element> object.
 
 =item pseudo
 
@@ -787,13 +790,19 @@ Expect inconsistency.
 
 To report bugs, please e-mail the author.
 
+=head1 ACKNOWLEDGEMENTS
+
+Thanks to Ville Skyttä, Nicholas Bamber and Gregor Herrmann for their
+contributions.
+
 =head1 AUTHOR & COPYRIGHT
 
-Copyright (C) 2007-10 Father Chrysostomos <sprout [at] cpan
+Copyright (C) 2007-15 Father Chrysostomos <sprout [at] cpan
 [dot] org>
 
 This program is free software; you may redistribute it and/or modify
-it under the same terms as perl.
+it under the same terms as perl. The full text of the license can be found
+in the LICENSE file included with this module.
 
 =head1 SEE ALSO
 
